#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 simple-get-opt
version:              0.4
visibility:           public
id:                   simple-get-opt-0.4-EOtqP13rrNoKxKzoxk8b26
key:                  simple-get-opt-0.4-EOtqP13rrNoKxKzoxk8b26
license:              BSD-3-Clause
maintainer:           iavor.diatchki@gmail.com
author:               Iavor S. Diatchki
synopsis:             A simple library for processing command-line options.
description:
    A simple library for processing command-line options.
    The library captures a common usage pattern of the GetOpt module
    form the standard libraries.

category:             Development
abi:                  a66dd056ecf3bcbd1fb54387186e6c26
exposed:              True
exposed-modules:      SimpleGetOpt
import-dirs:          /usr/lib/ghc-8.10.5/site-local/simple-get-opt-0.4
library-dirs:         /usr/lib/ghc-8.10.5/site-local/simple-get-opt-0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/simple-get-opt-0.4
hs-libraries:         HSsimple-get-opt-0.4-EOtqP13rrNoKxKzoxk8b26
depends:              base-4.14.2.0
haddock-interfaces:
    /usr/share/doc/haskell-simple-get-opt/html/simple-get-opt.haddock

haddock-html:         /usr/share/doc/haskell-simple-get-opt/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

